tlslite.errors.TLSFaultError

Package tlslite :: Module errors :: Class TLSFaultError |
[show private | hide private]
[frames | no frames]

## Class TLSFaultError

    Exception --+
                |
         TLSError --+
                    |
                   TLSFaultError

The other party responded incorrectly to an induced fault.

This exception will only occur during fault testing, when a TLSConnection's fault variable is set to induce some sort of faulty behavior, and the other party doesn't respond appropriately.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:56 2005 | http://epydoc.sf.net